/* DomainBlock.c generated by valac 0.56.19, the Vala compiler
 * generated from DomainBlock.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <glib.h>
#include <adwaita.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libsoup/soup.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE (tuba_views_admin_timeline_pagination_timeline_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))

typedef struct _TubaViewsAdminTimelinePaginationTimeline TubaViewsAdminTimelinePaginationTimeline;
typedef struct _TubaViewsAdminTimelinePaginationTimelineClass TubaViewsAdminTimelinePaginationTimelineClass;
typedef struct _TubaViewsAdminTimelinePaginationTimelinePrivate TubaViewsAdminTimelinePaginationTimelinePrivate;

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK (tuba_views_admin_timeline_domain_block_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK, TubaViewsAdminTimelineDomainBlock))
#define TUBA_VIEWS_ADMIN_TIMELINE_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK, TubaViewsAdminTimelineDomainBlockClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK))
#define TUBA_VIEWS_ADMIN_TIMELINE_DOMAIN_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK, TubaViewsAdminTimelineDomainBlockClass))

typedef struct _TubaViewsAdminTimelineDomainBlock TubaViewsAdminTimelineDomainBlock;
typedef struct _TubaViewsAdminTimelineDomainBlockClass TubaViewsAdminTimelineDomainBlockClass;
typedef struct _TubaViewsAdminTimelineDomainBlockPrivate TubaViewsAdminTimelineDomainBlockPrivate;
enum  {
	TUBA_VIEWS_ADMIN_TIMELINE_DOMAIN_BLOCK_0_PROPERTY,
	TUBA_VIEWS_ADMIN_TIMELINE_DOMAIN_BLOCK_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_timeline_domain_block_properties[TUBA_VIEWS_ADMIN_TIMELINE_DOMAIN_BLOCK_NUM_PROPERTIES];

#define TUBA_WIDGETS_ADMIN_TYPE_DOMAIN_BLOCK (tuba_widgets_admin_domain_block_get_type ())
#define TUBA_WIDGETS_ADMIN_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ADMIN_TYPE_DOMAIN_BLOCK, TubaWidgetsAdminDomainBlock))
#define TUBA_WIDGETS_ADMIN_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ADMIN_TYPE_DOMAIN_BLOCK, TubaWidgetsAdminDomainBlockClass))
#define TUBA_WIDGETS_ADMIN_IS_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ADMIN_TYPE_DOMAIN_BLOCK))
#define TUBA_WIDGETS_ADMIN_IS_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ADMIN_TYPE_DOMAIN_BLOCK))
#define TUBA_WIDGETS_ADMIN_DOMAIN_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ADMIN_TYPE_DOMAIN_BLOCK, TubaWidgetsAdminDomainBlockClass))

typedef struct _TubaWidgetsAdminDomainBlock TubaWidgetsAdminDomainBlock;
typedef struct _TubaWidgetsAdminDomainBlockClass TubaWidgetsAdminDomainBlockClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaViewsAdminTimelineDomainBlockOnRemoveRealData TubaViewsAdminTimelineDomainBlockOnRemoveRealData;

#define TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK (tuba_api_admin_domain_block_get_type ())
#define TUBA_API_ADMIN_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK, TubaAPIAdminDomainBlock))
#define TUBA_API_ADMIN_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK, TubaAPIAdminDomainBlockClass))
#define TUBA_API_ADMIN_IS_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK))
#define TUBA_API_ADMIN_IS_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK))
#define TUBA_API_ADMIN_DOMAIN_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK, TubaAPIAdminDomainBlockClass))

typedef struct _TubaAPIAdminDomainBlock TubaAPIAdminDomainBlock;
typedef struct _TubaAPIAdminDomainBlockClass TubaAPIAdminDomainBlockClass;

struct _TubaViewsAdminTimelinePaginationTimeline {
	GtkBox parent_instance;
	TubaViewsAdminTimelinePaginationTimelinePrivate * priv;
	GtkListBox* content;
};

struct _TubaViewsAdminTimelinePaginationTimelineClass {
	GtkBoxClass parent_class;
	void (*request) (TubaViewsAdminTimelinePaginationTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsAdminTimelinePaginationTimeline* self, GAsyncResult* _res_);
	GtkWidget* (*on_create_model_widget) (TubaViewsAdminTimelinePaginationTimeline* self, GObject* obj);
	void (*on_content_item_activated) (TubaViewsAdminTimelinePaginationTimeline* self, GtkListBoxRow* row);
};

struct _TubaViewsAdminTimelineDomainBlock {
	TubaViewsAdminTimelinePaginationTimeline parent_instance;
	TubaViewsAdminTimelineDomainBlockPrivate * priv;
};

struct _TubaViewsAdminTimelineDomainBlockClass {
	TubaViewsAdminTimelinePaginationTimelineClass parent_class;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaViewsAdminTimelineDomainBlockOnRemoveRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsAdminTimelineDomainBlock* self;
	TubaWidgetsAdminDomainBlock* widget;
	gchar* federation_block_id;
	AdwAlertDialog* dlg;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	AdwAlertDialog* _tmp4_;
	AdwAlertDialog* _tmp5_;
	AdwAlertDialog* _tmp6_;
	AdwAlertDialog* _tmp7_;
	AdwAlertDialog* _tmp8_;
	AdwAlertDialog* _tmp9_;
	AdwAlertDialog* _tmp10_;
	const gchar* _tmp11_;
	TubaRequestV2* req;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	TubaAccountStore* _tmp15_;
	TubaInstanceAccount* _tmp16_;
	TubaInstanceAccount* _tmp17_;
	TubaInstanceAccount* _tmp18_;
	TubaRequestV2* _tmp19_;
	TubaRequestV2* _tmp20_;
	TubaRequestV2* _tmp21_;
	GInputStream* _tmp22_;
	GInputStream* _tmp23_;
	GError* e;
	GError* _tmp24_;
	GError* _tmp25_;
	const gchar* _tmp26_;
	GError* _inner_error0_;
};

static gpointer tuba_views_admin_timeline_domain_block_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_views_admin_timeline_pagination_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelinePaginationTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_admin_timeline_domain_block_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelineDomainBlock, g_object_unref)
VALA_EXTERN GtkWidget* tuba_views_admin_timeline_pagination_timeline_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                                 GObject* obj);
static GtkWidget* tuba_views_admin_timeline_domain_block_real_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* base,
                                                                               GObject* obj);
VALA_EXTERN GType tuba_widgets_admin_domain_block_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAdminDomainBlock, g_object_unref)
static void tuba_views_admin_timeline_domain_block_on_remove (TubaViewsAdminTimelineDomainBlock* self,
                                                       TubaWidgetsAdminDomainBlock* widget,
                                                       const gchar* federation_block_id);
static void _tuba_views_admin_timeline_domain_block_on_remove_tuba_widgets_admin_domain_block_removed (TubaWidgetsAdminDomainBlock* _sender,
                                                                                                const gchar* federation_block_id,
                                                                                                gpointer self);
static void tuba_views_admin_timeline_domain_block_on_remove_real (TubaViewsAdminTimelineDomainBlock* self,
                                                            TubaWidgetsAdminDomainBlock* widget,
                                                            const gchar* federation_block_id,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
static void tuba_views_admin_timeline_domain_block_on_remove_real_finish (TubaViewsAdminTimelineDomainBlock* self,
                                                                   GAsyncResult* _res_);
static void tuba_views_admin_timeline_domain_block_on_remove_real_data_free (gpointer _data);
static gboolean tuba_views_admin_timeline_domain_block_on_remove_real_co (TubaViewsAdminTimelineDomainBlockOnRemoveRealData* _data_);
static void tuba_views_admin_timeline_domain_block_on_remove_real_ready (GObject* source_object,
                                                                  GAsyncResult* _res_,
                                                                  gpointer _user_data_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request_finish (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                   GAsyncResult* _res_);
VALA_EXTERN TubaViewsAdminTimelineDomainBlock* tuba_views_admin_timeline_domain_block_new (void);
VALA_EXTERN TubaViewsAdminTimelineDomainBlock* tuba_views_admin_timeline_domain_block_construct (GType object_type);
VALA_EXTERN TubaViewsAdminTimelinePaginationTimeline* tuba_views_admin_timeline_pagination_timeline_new (void);
VALA_EXTERN TubaViewsAdminTimelinePaginationTimeline* tuba_views_admin_timeline_pagination_timeline_construct (GType object_type);
static GObject * tuba_views_admin_timeline_domain_block_constructor (GType type,
                                                              guint n_construct_properties,
                                                              GObjectConstructParam * construct_properties);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_url (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            const gchar* value);
VALA_EXTERN GType tuba_api_admin_domain_block_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminDomainBlock, g_object_unref)
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_set_accepts (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                GType value);
static void tuba_views_admin_timeline_domain_block_finalize (GObject * obj);
static GType tuba_views_admin_timeline_domain_block_get_type_once (void);

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_views_admin_timeline_domain_block_on_remove_tuba_widgets_admin_domain_block_removed (TubaWidgetsAdminDomainBlock* _sender,
                                                                                           const gchar* federation_block_id,
                                                                                           gpointer self)
{
	tuba_views_admin_timeline_domain_block_on_remove ((TubaViewsAdminTimelineDomainBlock*) self, _sender, federation_block_id);
}

static GtkWidget*
tuba_views_admin_timeline_domain_block_real_on_create_model_widget (TubaViewsAdminTimelinePaginationTimeline* base,
                                                                    GObject* obj)
{
	TubaViewsAdminTimelineDomainBlock * self;
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_;
	TubaWidgetsAdminDomainBlock* action_row = NULL;
	GtkWidget* _tmp1_;
	TubaWidgetsAdminDomainBlock* _tmp2_;
	TubaWidgetsAdminDomainBlock* _tmp3_;
	GtkWidget* result;
	self = (TubaViewsAdminTimelineDomainBlock*) base;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_CLASS (tuba_views_admin_timeline_domain_block_parent_class)->on_create_model_widget (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline), obj);
	widget = _tmp0_;
	_tmp1_ = widget;
	_tmp2_ = _g_object_ref0 (TUBA_WIDGETS_ADMIN_IS_DOMAIN_BLOCK (_tmp1_) ? ((TubaWidgetsAdminDomainBlock*) _tmp1_) : NULL);
	action_row = _tmp2_;
	_tmp3_ = action_row;
	if (_tmp3_ != NULL) {
		TubaWidgetsAdminDomainBlock* _tmp4_;
		_tmp4_ = action_row;
		g_signal_connect_object (_tmp4_, "removed", (GCallback) _tuba_views_admin_timeline_domain_block_on_remove_tuba_widgets_admin_domain_block_removed, self, 0);
	}
	result = widget;
	_g_object_unref0 (action_row);
	return result;
}

static void
tuba_views_admin_timeline_domain_block_on_remove (TubaViewsAdminTimelineDomainBlock* self,
                                                  TubaWidgetsAdminDomainBlock* widget,
                                                  const gchar* federation_block_id)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (widget != NULL);
	g_return_if_fail (federation_block_id != NULL);
	tuba_views_admin_timeline_domain_block_on_remove_real (self, widget, federation_block_id, NULL, NULL);
}

static void
tuba_views_admin_timeline_domain_block_on_remove_real_data_free (gpointer _data)
{
	TubaViewsAdminTimelineDomainBlockOnRemoveRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->widget);
	_g_free0 (_data_->federation_block_id);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsAdminTimelineDomainBlockOnRemoveRealData, _data_);
}

static void
tuba_views_admin_timeline_domain_block_on_remove_real (TubaViewsAdminTimelineDomainBlock* self,
                                                       TubaWidgetsAdminDomainBlock* widget,
                                                       const gchar* federation_block_id,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_)
{
	TubaViewsAdminTimelineDomainBlockOnRemoveRealData* _data_;
	TubaViewsAdminTimelineDomainBlock* _tmp0_;
	TubaWidgetsAdminDomainBlock* _tmp1_;
	gchar* _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (widget != NULL);
	g_return_if_fail (federation_block_id != NULL);
	_data_ = g_slice_new0 (TubaViewsAdminTimelineDomainBlockOnRemoveRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_admin_timeline_domain_block_on_remove_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (widget);
	_g_object_unref0 (_data_->widget);
	_data_->widget = _tmp1_;
	_tmp2_ = g_strdup (federation_block_id);
	_g_free0 (_data_->federation_block_id);
	_data_->federation_block_id = _tmp2_;
	tuba_views_admin_timeline_domain_block_on_remove_real_co (_data_);
}

static void
tuba_views_admin_timeline_domain_block_on_remove_real_finish (TubaViewsAdminTimelineDomainBlock* self,
                                                              GAsyncResult* _res_)
{
	TubaViewsAdminTimelineDomainBlockOnRemoveRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_admin_timeline_domain_block_on_remove_real_ready (GObject* source_object,
                                                             GAsyncResult* _res_,
                                                             gpointer _user_data_)
{
	TubaViewsAdminTimelineDomainBlockOnRemoveRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_admin_timeline_domain_block_on_remove_real_co (_data_);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gboolean
tuba_views_admin_timeline_domain_block_on_remove_real_co (TubaViewsAdminTimelineDomainBlockOnRemoveRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		case 3:
		goto _state_3;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = adw_preferences_row_get_title ((AdwPreferencesRow*) _data_->widget);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = g_strdup_printf (_ ("Unblock %s?"), _data_->_tmp1_);
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = (AdwAlertDialog*) adw_alert_dialog_new (_data_->_tmp3_, NULL);
	g_object_ref_sink (_data_->_tmp4_);
	_data_->_tmp5_ = _data_->_tmp4_;
	_g_free0 (_data_->_tmp3_);
	_data_->dlg = _data_->_tmp5_;
	_data_->_tmp6_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp6_, "no", _ ("Cancel"));
	_data_->_tmp7_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp7_, "no", ADW_RESPONSE_DEFAULT);
	_data_->_tmp8_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp8_, "yes", _ ("Unblock"));
	_data_->_tmp9_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp9_, "yes", ADW_RESPONSE_DESTRUCTIVE);
	_data_->_tmp10_ = _data_->dlg;
	_data_->_state_ = 1;
	adw_alert_dialog_choose (_data_->_tmp10_, (GtkWidget*) _data_->self, NULL, tuba_views_admin_timeline_domain_block_on_remove_real_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp11_ = adw_alert_dialog_choose_finish (_data_->_tmp10_, _data_->_res_);
	if (g_strcmp0 (_data_->_tmp11_, "yes") == 0) {
		gtk_widget_set_sensitive ((GtkWidget*) _data_->widget, FALSE);
		_data_->_tmp12_ = string_to_string (_data_->federation_block_id);
		_data_->_tmp13_ = g_strconcat ("/api/v1/admin/domain_blocks/", _data_->_tmp12_, NULL);
		_data_->_tmp14_ = _data_->_tmp13_;
		_data_->_tmp15_ = tuba_accounts;
		_data_->_tmp16_ = tuba_account_store_get_active (_data_->_tmp15_);
		_data_->_tmp17_ = _data_->_tmp16_;
		_data_->_tmp18_ = _g_object_ref0 (_data_->_tmp17_);
		_data_->_tmp19_ = NULL;
		_data_->_tmp19_ = tuba_request_v2_new (_data_->_tmp14_, TUBA_REQUEST_V2_METHOD_DELETE);
		tuba_request_v2_set_account (_data_->_tmp19_, _data_->_tmp18_);
		_g_object_unref0 (_data_->_tmp18_);
		_data_->_tmp20_ = _data_->_tmp19_;
		_g_free0 (_data_->_tmp14_);
		_data_->req = _data_->_tmp20_;
		{
			_data_->_tmp21_ = _data_->req;
			_data_->_state_ = 2;
			tuba_request_v2_exec (_data_->_tmp21_, tuba_views_admin_timeline_domain_block_on_remove_real_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp22_ = tuba_request_v2_exec_finish (_data_->_tmp21_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->_tmp23_ = _data_->_tmp22_;
			_g_object_unref0 (_data_->_tmp23_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				goto __catch0_g_error;
			}
			gtk_widget_set_sensitive ((GtkWidget*) _data_->widget, TRUE);
			_data_->_state_ = 3;
			tuba_views_admin_timeline_pagination_timeline_request ((TubaViewsAdminTimelinePaginationTimeline*) _data_->self, tuba_views_admin_timeline_domain_block_on_remove_real_ready, _data_);
			return FALSE;
			_state_3:
			tuba_views_admin_timeline_pagination_timeline_request_finish ((TubaViewsAdminTimelinePaginationTimeline*) _data_->self, _data_->_res_);
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			gtk_widget_set_sensitive ((GtkWidget*) _data_->widget, TRUE);
			_data_->_tmp24_ = _data_->e;
			_data_->_tmp25_ = _data_->e;
			_data_->_tmp26_ = _data_->_tmp25_->message;
			g_signal_emit_by_name ((TubaViewsAdminTimelinePaginationTimeline*) _data_->self, "on-error", _data_->_tmp24_->code, _data_->_tmp26_);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->req);
			_g_object_unref0 (_data_->dlg);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		_g_object_unref0 (_data_->req);
	}
	_g_object_unref0 (_data_->dlg);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

TubaViewsAdminTimelineDomainBlock*
tuba_views_admin_timeline_domain_block_construct (GType object_type)
{
	TubaViewsAdminTimelineDomainBlock * self = NULL;
	self = (TubaViewsAdminTimelineDomainBlock*) tuba_views_admin_timeline_pagination_timeline_construct (object_type);
	return self;
}

TubaViewsAdminTimelineDomainBlock*
tuba_views_admin_timeline_domain_block_new (void)
{
	return tuba_views_admin_timeline_domain_block_construct (TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK);
}

static GObject *
tuba_views_admin_timeline_domain_block_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsAdminTimelineDomainBlock * self;
	parent_class = G_OBJECT_CLASS (tuba_views_admin_timeline_domain_block_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK, TubaViewsAdminTimelineDomainBlock);
	tuba_views_admin_timeline_pagination_timeline_set_url ((TubaViewsAdminTimelinePaginationTimeline*) self, "/api/v1/admin/domain_blocks");
	tuba_views_admin_timeline_pagination_timeline_set_accepts ((TubaViewsAdminTimelinePaginationTimeline*) self, TUBA_API_ADMIN_TYPE_DOMAIN_BLOCK);
	return obj;
}

static void
tuba_views_admin_timeline_domain_block_class_init (TubaViewsAdminTimelineDomainBlockClass * klass,
                                                   gpointer klass_data)
{
	tuba_views_admin_timeline_domain_block_parent_class = g_type_class_peek_parent (klass);
	((TubaViewsAdminTimelinePaginationTimelineClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsAdminTimelinePaginationTimeline*, GObject*)) tuba_views_admin_timeline_domain_block_real_on_create_model_widget;
	G_OBJECT_CLASS (klass)->constructor = tuba_views_admin_timeline_domain_block_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_timeline_domain_block_finalize;
}

static void
tuba_views_admin_timeline_domain_block_instance_init (TubaViewsAdminTimelineDomainBlock * self,
                                                      gpointer klass)
{
}

static void
tuba_views_admin_timeline_domain_block_finalize (GObject * obj)
{
	TubaViewsAdminTimelineDomainBlock * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_TIMELINE_TYPE_DOMAIN_BLOCK, TubaViewsAdminTimelineDomainBlock);
	g_debug ("DomainBlock.vala:3: Destroying DomainBlock");
	G_OBJECT_CLASS (tuba_views_admin_timeline_domain_block_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_timeline_domain_block_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminTimelineDomainBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_timeline_domain_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminTimelineDomainBlock), 0, (GInstanceInitFunc) tuba_views_admin_timeline_domain_block_instance_init, NULL };
	GType tuba_views_admin_timeline_domain_block_type_id;
	tuba_views_admin_timeline_domain_block_type_id = g_type_register_static (TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, "TubaViewsAdminTimelineDomainBlock", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_views_admin_timeline_domain_block_type_id;
}

GType
tuba_views_admin_timeline_domain_block_get_type (void)
{
	static GType tuba_views_admin_timeline_domain_block_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_timeline_domain_block_type_id__once)) {
		GType tuba_views_admin_timeline_domain_block_type_id;
		tuba_views_admin_timeline_domain_block_type_id = tuba_views_admin_timeline_domain_block_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_timeline_domain_block_type_id__once, tuba_views_admin_timeline_domain_block_type_id);
	}
	return tuba_views_admin_timeline_domain_block_type_id__once;
}

